@@ -1,3 +1,4 @@
+import click
 import pyfiglet
 
 from semi_ate_installer.state.state_machine import NewEnvSM
@@ -9,7 +10,8 @@ def print_semi_ate_installer_banner():
     print(ascii_banner)
 
 
-def main():
+@click.command()
+def run():
     print_semi_ate_installer_banner()
 
     state_machine = NewEnvSM()
@@ -17,5 +19,9 @@ def main():
         state_machine.next()
 
 
+def main():
+    run()
+
+
 if __name__ == "__main__":
     main()
